==> nextcloud-14.0.1.tgz: nextcloud/apps/support/l10n/fr.js <==
OC.L10N.register(
    "support",
    {
    "Link:" : "Lien :",
    "Password:" : "Mot de passe :",
    "Generating system report failed." : "La génération du rapport du système a échoué.",
    "Subscription notifications" : "Notifications d'abonnement",
    "Could not create folder \"System information\" to store generated report." : "Impossible de créer le dossier \"System information\" pour stocker le rapport généré.",
    "Could not create file \"%s\" to store generated report." : "Impossible de créer le fichier \"%s\" nécessaire à l'enregistrement du rapport.",
    "Could not share file \"%s\"." : "Impossible de partager le fichier \"%s\".",
    "Nextcloud Subscription" : "Abonnement Nextcloud",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "Votre serveur n'a pas de licence valide, ou elle a expirée.",
    "Your Nextcloud server subscription does not cover your number of users." : "Votre licence Nextcloud n'est pas suffisante pour votre nombre d'utilisateurs.",
    "Your Nextcloud Subscription has expired!" : "Votre licence Nextcloud a expirée !",
    "Your server has no Nextcloud Subscription or your Subscription has expired" : "Votre licence Nextcloud n'est pas suffisante pour votre nombre d'utilisateurs",
    "Your Nextcloud server is not backed by a Nextcloud Enterprise Subscription." : "Votre serveur Nextcloud n'a pas un abonnement Nextcloud Enterprise.",
    "A Nextcloud Support Subscription means the original developers behind your private cloud server are 100% dedicated to your success: the security, scalability, performance and functionality of your service!" : "Un abonnement au support Nextcloud signifie que les développeurs d'origine de votre serveur cloud privé sont dédiés à 100% à votre succès : la sécurité, l'évolutivité, la performance et la fonctionnalité à votre service !",
    "If you encounter a problem and your server does no longer work, blocking employees from sharing or customers from downloading and uploading files, you don't have to rely on searching online and asking volunteers on forums and social media for a solution. You have direct access to our experienced engineers who help you track down and fix the problem." : "Si vous rencontrez un problème et que votre serveur ne fonctionne plus, empêchant les employés de partager ou les clients de télécharger et de téléverser des fichiers, vous n'avez pas besoin de chercher en ligne et de demander aux bénévoles sur les forums et les médias sociaux de trouver une solution. Vous avez un accès direct à nos ingénieurs expérimentés qui vous aident à localiser et à résoudre le problème.",
    "You have a contract with the vendor providing confidential security information, mitigations, patches and updates." : "Vous avez un contrat avec le fournisseur qui fournit des renseignements confidentiels sur la sécurité, des mesures d'atténuation, des correctifs et des mises à jour.",
    "If you want to skip a release or two and stay a bit longer on your current version without disruptions, you don't have to run software without security updates. We deliver them to you as long as is needed!" : "Si vous voulez sauter une ou deux versions et rester un peu plus longtemps sur votre version actuelle sans interruption, vous n'avez pas besoin d'exécuter le logiciel sans mises à jour de sécurité. Nous vous les livrons aussi longtemps que nécessaire !",
    "If you have performance and scalability issues you have the best expertise at hand, instead of having to search on the web and hope you find a solution." : "Si vous avez des problèmes de performance et d'évolutivité, vous avez la meilleure expertise à portée de main, au lieu d'avoir à chercher sur le web et d'espérer trouver une solution.",
    "If you are asked how the compliance of Nextcloud is and if you can deliver a data export under GDPR, HIPAA or other rules, you have access to the right documentation and can tap into our expertise to respond quickly and accurately." : "Si on vous demande comment est la conformité de Nextcloud et si vous pouvez fournir une exportation de données sous RGPD, HIPAA ou d'autres règles, vous avez accès à la bonne documentation et pouvez puiser dans notre expertise pour répondre rapidement et précisément.",
    "We can also provide you Outlook integration, Online Office, scalable integrated audio-video and chat communication an other features only available in a very limited form for free. And we can develop further integrations and capabilities you need." : "Nous pouvons également vous fournir l'intégration d'Outlook, la suite Office en ligne, l'audio-vidéo intégré évolutif et la communication par chat ainsi que d'autres fonctionnalités disponibles uniquement sous une forme très limitée dans le cas d'une licence gratuite. Et nous pouvons développer d'autres intégrations et capacités dont vous avez besoin.",
    "A subscription helps you get the most out of Nextcloud! Don't your users deserve the best?" : "Un abonnement vous aide à tirer le meilleur parti de Nextcloud ! Vos utilisateurs ne méritent-ils pas ce qu'il y a de mieux ?",
    "Learn more now" : "En savoir plus maintenant",
    "Your Nextcloud server Subscription is over limit" : "Votre abonnement Nextcloud est au dessus de la limite.",
    "Dear admin," : "Cher administrateur,",
    "Your Nextcloud Subscription doesn't cover the number of users who are currently active on this server. Please contact you Nextcloud account manager to get your subscription updated!" : "Votre abonnement Nextcloud ne couvre plus le nombre d'utilisateur qui sont actuellement actifs sur votre serveur. Merci de contacter votre gestionnaire de compte Nextcloud pour mettre à niveau votre abonnement !",
    "%1$s is your account manager and can be reached by email via %2$s or by phone via %3$s." : "%1$s est votre gestionnaire de compte, il peut être contacté par e-mail à l'adresse %2$s ou par téléphone au %3$s.",
    "Thank you," : "Merci.",
    "Your Nextcloud team" : "Votre équipe Nextcloud",
    "Your Nextcloud server Subscription is expired" : "Votre abonnement Nextcloud est expiré",
    "Your Nextcloud server Subscription is expired!" : "Votre abonnement Nextcloud est expiré !",
    "Your Nextcloud Subscription has expired! Please contact you Nextcloud account manager to get your subscription updated!" : "Votre abonnement Nextcloud a expiré ! Merci de contacter votre gestionnaire de compte Nextcloud pour mettre à jour votre abonnement !",
    "Support" : "Prise en charge",
    "Getting support and help for your Nextcloud" : "Obtenir du soutien et de l'aide pour votre Nextcloud",
    "The support app covers you with direct access to help and consulting resources, dedicated contact options to your account manager and an overview of your enterprise subscription." : "L'application de support vous offre un accès direct à des ressources d'aide et de conseil, des options de contact dédiées à votre gestionnaire de compte et une vue d'ensemble de votre abonnement d'entreprise.",
    "Basic subscription" : "Abonnement basique",
    "Standard subscription" : "Abonnement standard",
    "Premium subscription" : "Abonnement premium",
    "Géant subscription" : "Abonnement Géant",
    "Silver partner subscription" : "Abonnement partenaire Silver",
    "Gold partner subscription" : "Abonnement partenaire Gold",
    "Subscription" : "Abonnement",
    "Over subscription limit" : "Au-delà de la limite de votre abonnement",
    "Valid subscription" : "Abonnement valide",
    "Expired subscription" : "Abonnement expiré",
    "Subscription key:" : "Clé de licence :",
    "_Expires in %n year_::_Expires in %n years_" : ["Expire dans %n an","Expire dans %n ans"],
    "_Expires in %n month_::_Expires in %n months_" : ["Expire dans %n mois","Expire dans %n mois"],
    "_Expires in %n week_::_Expires in %n weeks_" : ["Expire dans %n semaine","Expire dans %n semaines"],
    "_Expires in %n day_::_Expires in %n days_" : ["Expire dans %n jour","Expire dans %n jours"],
    "_For %n users_::_For %n users_" : ["Pour %n utilisateur","Pour %n utilisateurs"],
    "_currently at %n user_::_currently at %n users_" : ["Actuellement à %n utilisateur","Actuellement à %n utilisateurs"],
    "Includes support for %s" : "Inclut le support pour %s",
    "Includes support for %1$s & %2$s" : "Inclut le support pour %1$s & %2$s",
    "Includes support for %1$s, %2$s & %3$s" : "Inclut le support pour %1$s, %2$s & %3$s",
    "Update subscription key" : "Mettre à jour la clé de licence",
    "%s is your account manager. Don't hesitate to reach out to us if you have questions regarding your subscription." : "%s est votre gestionnaire de compte. N'hésitez pas à le contacter si vous avez des questions concernant votre abonnement.",
    "You can find answers to common question in our portal and also file support requests there." : "Vous pouvez trouver les réponses aux questions les plus courantes sur notre portail et y déposer des demandes d'assistance.",
    "Access Nextcloud portal" : "Accéder au portail Nextcloud",
    "System information" : "Informations système",
    "Collect system information for support cases. The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "Recueillir des informations sur le système pour les demandes de support. Le bouton ci-dessous génère un fichier texte dans le dossier \"System information\" et le partage comme lien public protégé par mot de passe. Le lien est valable 2 semaines.",
    "Generate system report" : "Générer un rapport système",
    "Enterprise subscription recommended" : "Abonnement d'entreprise recommandé",
    "No active enterprise subscription" : "Pas d'abonnement d'entreprise actif",
    "Unsupported" : "Non pris en charge",
    "This Nextcloud server has no Enterprise Subscription." : "Ce serveur Nextcloud n'a pas d'abonnement Entreprise.",
    "A Nextcloud Enterprise Subscription helps you get the most out of your Nextcloud, keep your data secure and your server working reliably at all times." : "L'abonnement Nextcloud Enterprise vous permet de tirer le meilleur parti de votre Nextcloud, de sécuriser vos données et de garantir la fiabilité de votre serveur à tout moment.",
    "Advantages" : "Avantages",
    "Access to the technical expertise of the Nextcloud developers through documentation and support" : "Accédez à l'expertise technique des développeurs Nextcloud par le biais de la documentation et du support.",
    "Access to additional capabilities like Outlook integration, online office and more" : "Accédez à des fonctionnalités supplémentaires telles que l'intégration d'Outlook, la suite Office en ligne et d'autres encore",
    "Access to scalability expertise and scalability capabilities for Files and Talk" : "Accès à l'expertise en matière d'évolutivité et aux capacités d'évolutivité pour les fichiers et les discussions",
    "Optional branding, consulting, architecture advice" : "En option : branding, conseil, conseil en architecture.",
    "Confidential security notification service, mitigations, patches and advice" : "Service d'avis de sécurité confidentiel, atténuation, correctifs et conseils",
    "Compliance certification, advice and documentation" : "Certification de conformité, conseils et documentation",
    "Get a quote" : "Obtenir un devis",
    "More information" : "Plus d'informations",
    "Subscription benefits" : "Avantages de l'abonnement",
    "Pricing" : "Tarifs",
    "Commmunity support" : "Soutien communautaire",
    "Forum" : "Forum",
    "Nextcloud is free software which is supported by a very active community. Please register at the forum to ask questions and discuss with others." : "Nextcloud est un logiciel libre soutenu par une communauté très active. Veuillez vous inscrire sur le forum pour poser des questions et discuter avec les autres utilisateurs.",
    "Nextcloud forum" : "Forum Nextcloud",
    "GitHub" : "GitHub",
    "Nextcloud uses GitHub as platform to collaboratively work. You can file bug reports directly there." : "Nextcloud utilise GitHub comme plateforme de travail collaboratif. Vous pouvez y classer les rapports de bogue directement.",
    "Nextcloud at GitHub" : "Nextcloud chez GitHub",
    "Chat" : "Chat",
    "Chat with us on our IRC channel #nextcloud on Freenode." : "Discutez avec nous sur notre canal IRC #nextcloud sur Freenode.",
    "Open chat" : "Ouvrir le chat",
    "Subscription key" : "Clé de licence",
    "If you have an active Nextcloud Subscription please enter your subscription key here." : "Si vous avez un abonnement Nextcloud actif, veuillez entrer votre clé de licence ici.",
    "Learn more about an enterprise subscription." : "En savoir plus sur un abonnement d'entreprise.",
    "Set subscription key" : "Définir la clé de licence",
    "The subscription info could not properly fetched right now. A retry is scheduled. Please check back later." : "Les informations d'abonnement n'ont pas pu être récupérées correctement en ce moment. Un nouvel essai est prévu. Veuillez vérifier plus tard.",
    "The subscription key was invalid." : "La clé de licence est invalide.",
    "The subscription key could not be verified, because this server has no internet connection. Please reach out to the support team to get this resolved." : "La clé de licence n'a pas pu être vérifiée car ce serveur n'a pas de connexion Internet. Veuillez contacter l'équipe de support pour résoudre ce problème.",
    "The subscription key had an invalid format." : "La clé de licence a un format invalide.",
    "While fetching the subscription information an error happened." : "Une erreur s'est produite lors de la récupération des informations d'abonnement.",
    "News" : "Nouveautés",
    "To get up to date information what is going on at Nextcloud sign up for the newsletter and follow us on our social media accounts." : "Pour obtenir des informations à jour sur ce qui se passe chez Nextcloud, inscrivez-vous à la newsletter et suivez-nous sur nos réseaux sociaux.",
    "Follow us on Google+" : "Suivez-nous sur Google+",
    "Like our Facebook page" : "Aimez notre page Facebook",
    "Follow us on Twitter" : "Suivez-nous sur Twitter",
    "Check out our blog" : "Visitez notre blog",
    "Subscribe to our newsletter" : "Inscrivez-vous à notre newsletter"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-15.0.5p1.tgz: nextcloud/apps/support/l10n/fr.js <==
OC.L10N.register(
    "support",
    {
    "Link:" : "Lien :",
    "Password:" : "Mot de passe :",
    "Generating system report failed." : "La génération du rapport du système a échoué.",
    "Subscription notifications" : "Notifications d'abonnement",
    "Could not create folder \"System information\" to store generated report." : "Impossible de créer le dossier \"System information\" pour stocker le rapport généré.",
    "Could not create file \"%s\" to store generated report." : "Impossible de créer le fichier \"%s\" nécessaire à l'enregistrement du rapport.",
    "Could not share file \"%s\"." : "Impossible de partager le fichier \"%s\".",
    "Nextcloud Subscription" : "Abonnement Nextcloud",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "Votre serveur n'a pas de licence valide, ou elle a expirée.",
    "Your Nextcloud server subscription does not cover your number of users." : "Votre licence Nextcloud n'est pas suffisante pour votre nombre d'utilisateurs.",
    "Your Nextcloud Subscription has expired!" : "Votre licence Nextcloud a expirée !",
    "Your server has no Nextcloud Subscription" : "Votre serveur n'a pas d'abonnement Nextcloud",
    "Your Nextcloud server is not backed by a Nextcloud Enterprise Subscription." : "Votre serveur Nextcloud n'a pas un abonnement Nextcloud Enterprise.",
    "You have access to the right documentation and expertise to quickly answer compliance questions or deliver on GDPR, HIPAA and other regulation requirements." : "Vous avez accès à la documentation pertinente et à l'expertise pour répondre rapidement aux questions de conformité et aux engagements sur le RGPD, le HIPAA (assurance maladie aux Etats-Unis) et les autres exigences réglementaires.",
    "A subscription helps you get the most out of Nextcloud!" : "Un abonnement vous aide à tirer le meilleur parti de Nextcloud !",
    "Learn more now" : "En savoir plus maintenant",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %1$s because you have over %2$s registered users." : "Cet e-mail a été envoyé à tous les administrateurs par l'application de prise en charge de votre instance Nextcloud chez %1$s parce que vous avez plus de %2$s utilisateurs enregistrés.",
    "Your Nextcloud server Subscription is over limit" : "Votre abonnement Nextcloud est au dessus de la limite.",
    "Dear admin," : "Cher administrateur,",
    "Your Nextcloud Subscription doesn't cover the number of users who are currently active on this server. Please contact your Nextcloud account manager to get your subscription updated!" : "Votre abonnement Nextcloud ne couvre pas le nombre d'utilisateurs qui sont actuellement actifs sur votre serveur. Merci de contacter votre gestionnaire de compte Nextcloud pour mettre à niveau votre abonnement !",
    "%1$s is your account manager and can be reached by email via %2$s or by phone via %3$s." : "%1$s est votre gestionnaire de compte, il peut être contacté par e-mail à l'adresse %2$s ou par téléphone au %3$s.",
    "Thank you," : "Merci.",
    "Your Nextcloud team" : "Votre équipe Nextcloud",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because you have more users than your subscription covers." : "Cet e-mail a été envoyé à tous les administrateurs par l'application de prise en charge de votre instance Nextcloud chez %s parce que vous avez plus d’utilisateurs que ce que votre abonnement le permet.",
    "Your Nextcloud server Subscription is expired" : "Votre abonnement Nextcloud est expiré",
    "Your Nextcloud server Subscription is expired!" : "Votre abonnement Nextcloud est expiré !",
    "Your Nextcloud Subscription has expired! Please contact your Nextcloud account manager to get your subscription updated!" : "Votre abonnement Nextcloud a expiré ! Merci de contacter votre gestionnaire de compte Nextcloud pour mettre à jour votre abonnement !",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because your subscription expired." : "Cet e-mail a été envoyé à tous les administrateurs par l'application de prise en charge de votre instance Nextcloud chez %s parce que votre abonnement a expiré.",
    "Support" : "Prise en charge",
    "Getting support and help for your Nextcloud" : "Obtenir du soutien et de l'aide pour votre Nextcloud",
    "The support app covers you with direct access to help and consulting resources, dedicated contact options to your account manager and an overview of your enterprise subscription." : "L'application de support vous offre un accès direct à des ressources d'aide et de conseil, des options de contact dédiées à votre gestionnaire de compte et une vue d'ensemble de votre abonnement d'entreprise.",
    "Basic subscription" : "Abonnement basique",
    "Standard subscription" : "Abonnement standard",
    "Premium subscription" : "Abonnement premium",
    "Géant subscription" : "Abonnement Géant",
    "Silver partner subscription" : "Abonnement partenaire Silver",
    "Gold partner subscription" : "Abonnement partenaire Gold",
    "Subscription" : "Abonnement",
    "Over subscription limit" : "Au-delà de la limite de votre abonnement",
    "Valid subscription" : "Abonnement valide",
    "Expired subscription" : "Abonnement expiré",
    "Subscription key:" : "Clé de licence :",
    "_Expires in %n year_::_Expires in %n years_" : ["Expire dans %n an","Expire dans %n ans"],
    "_Expires in %n month_::_Expires in %n months_" : ["Expire dans %n mois","Expire dans %n mois"],
    "_Expires in %n week_::_Expires in %n weeks_" : ["Expire dans %n semaine","Expire dans %n semaines"],
    "_Expires in %n day_::_Expires in %n days_" : ["Expire dans %n jour","Expire dans %n jours"],
    "For an unlimited amount of users" : "Pour un nombre illimité d'utilisateurs",
    "_For %n active users_::_For %n active users_" : ["Pour %n utilisateur actif","Pour %n utilisateurs actifs"],
    "_For %n users_::_For %n users_" : ["Pour %n utilisateur","Pour %n utilisateurs"],
    "_currently at %n user_::_currently at %n users_" : ["Actuellement à %n utilisateur","Actuellement à %n utilisateurs"],
    "Includes support for %s" : "Inclut le support pour %s",
    "Includes support for %1$s & %2$s" : "Inclut le support pour %1$s & %2$s",
    "Includes support for %1$s, %2$s & %3$s" : "Inclut le support pour %1$s, %2$s & %3$s",
    "Update subscription key" : "Mettre à jour la clé de licence",
    "%s is your account manager. Don't hesitate to reach out to us if you have questions regarding your subscription." : "%s est votre gestionnaire de compte. N'hésitez pas à le contacter si vous avez des questions concernant votre abonnement.",
    "You can find answers to common question in our portal and also file support requests there." : "Vous pouvez trouver les réponses aux questions les plus courantes sur notre portail et y déposer des demandes d'assistance.",
    "Access Nextcloud portal" : "Accéder au portail Nextcloud",
    "System information" : "Informations système",
    "Collect system information for support cases. The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "Recueillir des informations sur le système pour les demandes de support. Le bouton ci-dessous génère un fichier texte dans le dossier \"System information\" et le partage comme lien public protégé par mot de passe. Le lien est valable 2 semaines.",
    "Generate system report" : "Générer un rapport système",
    "Enterprise subscription recommended" : "Abonnement d'entreprise recommandé",
    "No active enterprise subscription" : "Pas d'abonnement d'entreprise actif",
    "Unsupported" : "Non pris en charge",
    "This Nextcloud server has no Enterprise Subscription." : "Ce serveur Nextcloud n'a pas d'abonnement Entreprise.",
    "A Nextcloud Enterprise Subscription helps you get the most out of your Nextcloud, keep your data secure and your server working reliably at all times." : "L'abonnement Nextcloud Enterprise vous permet de tirer le meilleur parti de votre Nextcloud, de sécuriser vos données et de garantir la fiabilité de votre serveur à tout moment.",
    "Advantages" : "Avantages",
    "Access to the technical expertise of the Nextcloud developers through documentation and support" : "Accédez à l'expertise technique des développeurs Nextcloud par le biais de la documentation et du support.",
    "Access to additional capabilities like Outlook integration, online office and more" : "Accédez à des fonctionnalités supplémentaires telles que l'intégration d'Outlook, la suite Office en ligne et d'autres encore",
    "Access to scalability expertise and scalability capabilities for Files and Talk" : "Accès à l'expertise en matière d'évolutivité et aux capacités d'évolutivité pour les fichiers et les discussions",
    "Optional branding, consulting, architecture advice" : "En option : branding, conseil, conseil en architecture.",
    "Confidential security notification service, mitigations, patches and advice" : "Service d'avis de sécurité confidentiel, atténuation, correctifs et conseils",
    "Compliance certification, advice and documentation" : "Certification de conformité, conseils et documentation",
    "Get a quote" : "Obtenir un devis",
    "More information" : "Plus d'informations",
    "Subscription benefits" : "Avantages de l'abonnement",
    "Pricing" : "Tarifs",
    "Commmunity support" : "Soutien communautaire",
    "Forum" : "Forum",
    "Nextcloud is free software which is supported by a very active community. Please register at the forum to ask questions and discuss with others." : "Nextcloud est un logiciel libre soutenu par une communauté très active. Veuillez vous inscrire sur le forum pour poser des questions et discuter avec les autres utilisateurs.",
    "GitHub" : "GitHub",
    "Nextcloud uses GitHub as platform to collaboratively work. You can file bug reports directly there." : "Nextcloud utilise GitHub comme plateforme de travail collaboratif. Vous pouvez y classer les rapports de bogue directement.",
    "Chat" : "Chat",
    "Chat with us on our IRC channel #nextcloud on Freenode." : "Discutez avec nous sur notre canal IRC #nextcloud sur Freenode.",
    "Nextcloud forum" : "Forum Nextcloud",
    "Nextcloud at GitHub" : "Nextcloud chez GitHub",
    "Open chat" : "Ouvrir le chat",
    "Subscription key" : "Clé de licence",
    "If you have an active Nextcloud Subscription please enter your subscription key here." : "Si vous avez un abonnement Nextcloud actif, veuillez entrer votre clé de licence ici.",
    "Learn more about an enterprise subscription." : "En savoir plus sur un abonnement d'entreprise.",
    "Set subscription key" : "Définir la clé de licence",
    "The subscription info could not properly fetched right now. A retry is scheduled. Please check back later." : "Les informations d'abonnement n'ont pas pu être récupérées correctement en ce moment. Un nouvel essai est prévu. Veuillez vérifier plus tard.",
    "The subscription key was invalid." : "La clé de licence est invalide.",
    "The subscription key could not be verified, because this server has no internet connection. Please reach out to the support team to get this resolved." : "La clé de licence n'a pas pu être vérifiée car ce serveur n'a pas de connexion Internet. Veuillez contacter l'équipe de support pour résoudre ce problème.",
    "The subscription key had an invalid format." : "La clé de licence a un format invalide.",
    "While fetching the subscription information an error happened." : "Une erreur s'est produite lors de la récupération des informations d'abonnement.",
    "News" : "Nouveautés",
    "To get up to date information what is going on at Nextcloud sign up for the newsletter and follow us on our social media accounts." : "Pour obtenir des informations à jour sur ce qui se passe chez Nextcloud, inscrivez-vous à la newsletter et suivez-nous sur nos réseaux sociaux.",
    "Like our Facebook page" : "Aimez notre page Facebook",
    "Follow us on Twitter" : "Suivez-nous sur Twitter",
    "Check out our blog" : "Visitez notre blog",
    "Subscribe to our newsletter" : "Inscrivez-vous à notre newsletter"
},
"nplurals=2; plural=(n > 1);");
